orichain.llm
====================

Module contents
---------------

.. automodule:: orichain.llm
   :members:
   :undoc-members:
   :special-members: __init__, __call__
   :exclude-members: model_handler, supported_models
   :show-inheritance:

Submodules
----------

orichain.llm.anthropic\_llm module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: orichain.llm.anthropic_llm
   :members:
   :undoc-members:
   :special-members: __init__, __call__
   :show-inheritance:

orichain.llm.anthropicbedrock\_llm module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: orichain.llm.anthropicbedrock_llm
   :members:
   :undoc-members:
   :special-members: __init__, __call__
   :show-inheritance:

orichain.llm.awsbedrock\_llm module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: orichain.llm.awsbedrock_llm
   :members:
   :undoc-members:
   :special-members: __init__, __call__
   :exclude-members: CreateAiter
   :show-inheritance:

orichain.llm.azureopenai\_llm module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: orichain.llm.azureopenai_llm
   :members:
   :undoc-members:
   :special-members: __init__, __call__
   :exclude-members: num_tokens_from_string
   :show-inheritance:

orichain.llm.gcp\_gemini\_llm module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: orichain.llm.gcp_gemini_llm
   :members:
   :undoc-members:
   :special-members: __init__, __call__
   :show-inheritance:

orichain.llm.gcp\_vertex\_llm module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: orichain.llm.gcp_vertex_llm
   :members:
   :undoc-members:
   :special-members: __init__, __call__
   :show-inheritance:

orichain.llm.openai\_llm module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: orichain.llm.openai_llm
   :members:
   :undoc-members:
   :special-members: __init__, __call__
   :exclude-members: num_tokens_from_string
   :show-inheritance:
